

# Semicpy : Semiconductor physics calculation and modeling

## What is it?

**Semicpy** is a python package that allows you to model semiconductors and perform calculations with them.

## Main Features

   - instantiate semiconductors as objects for calculations and modeling
   - perform data analysis on semiconductors
   - etc.

## Installation

    pip install semicpy

## Future considerations

   - Try implementing some form of machine learning/deep learning
   - Magnetic Semiconductors
   - New device topologies
   - New materials!

## Source Code

The source code is currently hosted on [GitHub](https://github.com/nkskumar/semic)

## Dependencies

   - Numpy
   - pandas
   - Pint
   - Scipy
   - Plotly
   - Matplotlib
   - seaborn

## License

[MIT](LICENSE)

## Documentation

Documentation for this package will be hosted on ReadTheDocs soon.

## Author

This package is written by [Nithin Kumar Santha Kumar](https://twitter.com/nithin_ksk)

## Background

This package was started as a result of the author's desire for an open source library that could provide a comprehensive calculation and modeling system that would be useful for everyone from university students to industry professionals.

## Contributions

All contributors are welcome! Please email [me](mailto:nithinkumar.santhakumar@utdallas.edu)!

## Bugs and Issues

Head on over to [Issues tracker](https://github.com/nkskumar/semic/issues)

## References

[References](REFERENCES.md)
